/*--------------------------------------------------------------
    Minimal Styles
--------------------------------------------------------------*/

.blog-single-entry.post-minimal .post-header, .blog-single-entry.post-minimal .post-meta,
.blog-single-entry.post-minimal .single-entry-body, .blog-single-entry.post-minimal .single-entry-body figure figcaption,
.blog-single-entry.post-minimal #comments { margin-left: auto; margin-right: auto; max-width: 1000px; }

	/* Post Minimal Header */

	.blog-single-entry.post-minimal .post-header { position: relative; text-align: center; margin-bottom: 40px; }

	.blog-single-entry.post-minimal .single-entry-title,
	.blog-single-entry.post-minimal .post-header .single-entry-title,
	.blog-single-entry.post-minimal .post-header .single-entry-date,
	.blog-single-entry.post-minimal .post-header .single-entry-categories { line-height: normal; }

	.blog-single-entry.post-minimal .post-header .single-entry-categories a { border-width: 0; display: inline-block; font-size: calc(var(--wdtFontSize_Base) - 3px); font-weight: 600; line-height: normal; letter-spacing: 1px; position: relative; text-transform: none; white-space: nowrap; }

	.blog-single-entry.post-minimal .post-header .single-entry-categories a:hover { background: transparent; }

    .blog-single-entry.post-minimal .post-header .single-entry-categories a:not(:last-child) { position: relative; white-space: nowrap; }
    .blog-single-entry.post-minimal .post-header .single-entry-categories a:not(:last-child):after { content: '\002C'; display: inline; font-size: var(--wdtFontSize_Base); line-height: 1; margin-left: 0;  }

    .wdt-post-entry .blog-entry div.entry-categories a:last-child:after, .wdt-post-entry .blog-entry div.entry-tags a:last-child:after, .wdt-post-entry .blog-entry div.entry-categories a:only-child:after, .wdt-post-entry .blog-entry div.entry-tags a:only-child:after { display: none; }

	.blog-single-entry.post-minimal .post-header .single-entry-title { margin-bottom: 0; }

	.blog-single-entry.post-minimal .post-header .single-entry-title, .blog-single-entry.post-minimal .single-entry-title { display: inline-block; float: none; position: relative; width: 100%; line-height: 0; text-align: center; }

	.blog-single-entry.post-minimal .post-header .single-entry-title span.sticky-post,
	.blog-single-entry.post-minimal > .single-entry-title span.sticky-post,
	.blog-single-entry.post-minimal .single-entry-body .single-entry-title span.sticky-post  { display: inline-block; font-size: calc(var(--wdtFontSize_Base) - 4px); font-weight: var(--wdtFontWeight_Alt); margin-bottom: 5px; padding: 10px 12px; text-transform: uppercase; -webkit-border-radius: var(--wdtRadius_2X); border-radius: var(--wdtRadius_2X); }

	.blog-single-entry.post-minimal .post-header .single-entry-title h1, .blog-single-entry.post-minimal .single-entry-title h1 { display: inline-block; font-size: var(--wdtFontSize_H2); margin: 0 0 15px; text-transform: none; width: 100%; word-wrap: break-word; }

	.blog-single-entry.post-minimal .single-entry-title h1 { margin-bottom: 0; }

	.blog-single-entry.post-minimal .post-header .single-entry-date { border: none; display: inline-block; font-size: calc(var(--wdtFontSize_Base) - 3px); font-weight: 600; letter-spacing: 1px; padding: 0 40px; position: relative; text-transform: none; width: auto; }

	.blog-single-entry.post-minimal .post-header .single-entry-date:hover { background: none; color: var(--wdtBodyTxtColor); }

	.blog-single-entry.post-minimal .post-header .single-entry-date,
	.blog-single-entry.post-minimal .post-header .single-entry-categories { margin: 0 0 10px; }

	.blog-single-entry.post-minimal .post-header .single-entry-date:before, .blog-single-entry.post-minimal .post-header .single-entry-date:after { position: absolute; top: 50%; overflow: hidden; width: 24px; height: 1px; border-top: 1px solid; content: ''; }

	.blog-single-entry.post-minimal .post-header .single-entry-date:before{ left: 0; }

	.blog-single-entry.post-minimal .post-header .single-entry-date:after { right: 0; }

	.blog-single-entry.post-minimal .blog-image img,
	.blog-single-entry.post-minimal .blog-image iframe,
	.blog-single-entry.post-minimal .blog-image .wdt-video-wrap { display: inline-block; float: none; margin-bottom: 60px; }
	.blog-single-entry.post-minimal .blog-image .wdt-video-wrap { width: 100%; }


	/* Post Minimal Post Meta */

	.blog-single-entry.post-minimal .post-meta { border-style: solid; border-width: 1px 0; display: flex; align-items: center; justify-content: space-between; flex-wrap: wrap; margin-bottom: 30px; padding: 15px 0; }

	.blog-single-entry.post-minimal .post-meta > [class*="meta"] { display: flex; align-items: center; }

	.blog-single-entry.post-minimal .post-meta > [class*="meta"] div[class*="entry-"] { margin: 0; }

	.blog-single-entry.post-minimal .post-meta > [class*="meta"] div[class*="entry-"], .blog-single-entry.post-minimal .single-entry-author { line-height: normal; display: flex; }

	.blog-single-entry.post-minimal .post-meta .single-entry-author, .blog-single-entry.post-minimal .single-entry-author { align-items: center; }

	.blog-single-entry.post-minimal .post-meta .single-entry-author .meta-author-img, .blog-single-entry.post-minimal .single-entry-author .meta-author-img { margin-right: 10px; }

	.blog-single-entry.post-minimal .post-meta .single-entry-author .meta-author-img img, .blog-single-entry.post-minimal .single-entry-author .meta-author-img img { margin: 0; border-radius: 100%; }

	.blog-single-entry.post-minimal .single-entry-author .meta-author-info span,
	.blog-single-entry.post-minimal .post-meta .single-entry-author .meta-author-info span { display: block; font-size: calc(var(--wdtFontSize_Base) - 3px); font-weight: var(--wdtFontWeight_Base); margin-bottom: 2px; text-transform: none; }

	.blog-single-entry.post-minimal .single-entry-author .meta-author-info a,
	.blog-single-entry.post-minimal .post-meta .single-entry-author .meta-author-info > a { font-size: var(--wdtFontSize_Base); font-weight: 600; letter-spacing: 0; text-transform: none; }

	.blog-single-entry.post-minimal .post-meta .single-entry-social-share > .share { border: none; padding: 0; }

	.blog-single-entry.post-minimal .post-meta .single-entry-social-share > .share > i { display: none; }

	.blog-single-entry.post-minimal .post-meta .single-entry-social-share ul { display: flex; list-style: none; margin-bottom: 0; }
	.blog-single-entry.post-minimal .post-meta .single-entry-social-share ul,
	.blog-single-entry.post-minimal .post-meta .single-entry-social-share ul li { padding: 0; }

	.blog-single-entry.post-minimal .post-meta .single-entry-social-share > .share .wdt-share-list:before, .blog-single-entry.post-minimal .post-meta .single-entry-social-share > .share .wdt-share-list:after { content: none; }

	.blog-single-entry.post-minimal .post-meta .single-entry-social-share ul li,
	.blog-single-entry.post-minimal .single-entry-body .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list li, .blog-single-entry.post-minimal .single-entry-body .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list li, .blog-single-entry.post-minimal > .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list li, .blog-single-entry.post-minimal > .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list li { list-style: none; margin: 0; padding: 0; }

	.blog-single-entry.post-minimal .post-meta .single-entry-social-share ul li a { width: 32px; height: 32px; text-align: center; float: left; font-size: 14px; border-radius: 100%; display: flex; justify-content: center; align-items: center; border: 1px solid; }

	.blog-single-entry.post-minimal .post-meta .single-entry-social-share ul li:not(:last-child) a,
	.blog-single-entry.post-minimal .single-entry-body .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list li:not(:last-child) a, .blog-single-entry.post-minimal .single-entry-body .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list li:not(:last-child) a, .blog-single-entry.post-minimal > .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list li:not(:last-child) a, .blog-single-entry.post-minimal > .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list li:not(:last-child) a { margin-right: 5px; }

	.blog-single-entry.post-minimal .post-meta .single-entry-comments .comment-wrap { margin-left: 20px; }
	.blog-single-entry.post-minimal .post-meta .single-entry-comments .comment-wrap a { min-width: 32px; min-height: 30px; border-width: 1px; border-style: solid; text-align: center; font-weight: 400; border-radius: 2px; font-size: 12px; position: relative; display: flex; justify-content: center; align-items: center; padding: 0 10px; }

	.blog-single-entry.post-minimal .post-meta .single-entry-comments .comment-wrap a:before { content: ""; width: 0; height: 0; position: absolute; border-left: 6px solid; border-right: 6px solid; border-top: 6px solid; border-bottom: 6px solid; border-left-color: transparent !important; border-right-color: transparent !important; border-bottom-color: transparent !important; bottom: 0; left: 0; right: 0; margin: auto; transform: translateY(100%); -webkit-transform: translateY(100%); -moz-transform: translateY(100%); top: auto; }

	.blog-single-entry.post-minimal .post-meta .single-entry-comments .comment-wrap a:after { content: ""; width: 0; height: 0; position: absolute; border-left: 6px solid transparent; border-right: 6px solid transparent; border-top: 6px solid var(--wdtBodyBGColor); border-bottom: 6px solid transparent; right: 0; margin: auto; bottom: 0; left: 0; transform: translateY(90%); -moz-transform: translateY(90%); -webkit-transform: translateY(90%); top: auto; }

	/* Post Minimal Content */

	.blog-single-entry.post-minimal .single-entry-body { float: none; margin: auto; display: block; }
	.blog-single-entry.post-minimal .single-entry-body .wdt-post-teaser { color: var(--wdtBodyTxtColor); font-size: var(--wdtFontSize_H6); font-style: italic; line-height: var(--wdtLineHeight_Alt); margin-bottom: 25px; }

	.blog-single-entry.post-minimal .single-entry-body .wdt-custom-minimal-image-section img { margin-bottom: 10px; }

	.blog-single-entry.post-minimal .single-entry-body .wdt-elementor-ordered-list-items { margin: 0; }

	.blog-single-entry.post-minimal .single-entry-body figure figcaption { display: inline-block; font-size: calc(var(--wdtFontSize_Base) - 2px); line-height: 1.7; text-align: center; width: 100%; }

	.blog-single-entry.post-minimal .single-entry-body figure.wp-block-image figcaption { border-width: 0; padding-bottom: 0; text-align: center; }

	.page-with-sidebar .blog-single-entry.post-minimal .post-header, .page-with-sidebar .blog-single-entry.post-minimal .post-meta,
	.page-with-sidebar .blog-single-entry.post-minimal .single-entry-body, .page-with-sidebar .blog-single-entry.post-minimal .single-entry-body figure figcaption,
	.page-with-sidebar .blog-single-entry.post-minimal #comments { margin-left: 0; margin-right: 0; max-width: 100%; }

	.blog-single-entry.post-minimal .single-entry-body figure figcaption.blocks-gallery-caption, .blog-single-entry.post-minimal .single-entry-body figure figcaption.blocks-gallery-caption { border-bottom-width: 0; }

	.blog-single-entry.post-minimal .single-entry-body div i[class*="fa"], .blog-single-entry.post-minimal .single-entry-body div i.pe, .blog-single-entry.post-minimal .single-entry-body div.single-entry-social-share:not(.meta-elements) i[class*="fa"],
	.blog-single-entry.post-minimal .single-entry-body div.single-entry-social-share:not(.meta-elements) i.pe, .blog-single-entry.post-minimal .single-entry-social-share .share i[class*="fa"], .blog-single-entry.post-minimal .single-entry-social-share .share i.pe { display: none; }

	.blog-single-entry.post-minimal .single-entry-body div.single-entry-social-share[class*="meta-elements"] i[class*="fa"],
	.blog-single-entry.post-minimal .single-entry-body div.single-entry-social-share[class*="meta-elements"] i.pe { display: inline-block; }

	.blog-single-entry.post-minimal .single-entry-body div.single-entry-comments i[class*="fa"], .blog-single-entry.post-minimal .single-entry-body div.single-entry-comments i.pe, .blog-single-entry.post-minimal .single-entry-body div.single-entry-likes-views i[class*="fa"], .blog-single-entry.post-minimal .single-entry-body div.single-entry-likes-views i.pe { display: inline-block; }

	.blog-single-entry.post-minimal .single-entry-body div[class*="meta-elements"].single-entry-categories a:not(:last-child):after,
	.blog-single-entry.post-minimal .single-entry-body div[class*="meta-elements"].single-entry-tags a:not(:last-child):after { content: none; }

	.blog-single-entry.post-minimal > .single-entry-comments a,

	.blog-single-entry.post-minimal > .single-entry-tags a, .blog-single-entry.post-minimal > .single-entry-categories a,
	.blog-single-entry.post-minimal > .single-entry-body > .single-entry-tags a, .blog-single-entry.post-minimal > .single-entry-body > .single-entry-categories a,

	.blog-single-entry.post-minimal > .single-entry-body > .single-entry-date, .blog-single-entry.post-minimal > .single-entry-date,

	.blog-single-entry.post-minimal > .single-entry-body > .single-entry-author { font-size: 10px; font-weight: 400; letter-spacing: 1px; text-transform: uppercase; border: 1px solid; padding: 5px 10px; line-height: normal; display: inline-block; width: auto; }

	.blog-single-entry.post-minimal > .single-entry-tags a:not(:last-child), .blog-single-entry.post-minimal > .single-entry-categories a:not(:last-child),
	.blog-single-entry.post-minimal > .single-entry-body .single-entry-tags a:not(:last-child), .blog-single-entry.post-minimal > .single-entry-body .single-entry-categories a:not(:last-child) { margin: 0 2px 0 0; }

	.blog-single-entry.post-minimal > .single-entry-categories a:not(:last-child):after,
	.blog-single-entry.post-minimal > .single-entry-tags a:not(:last-child):after,
	.blog-single-entry.post-minimal > .single-entry-body .single-entry-tags a:not(:last-child):not(:only-child):after,
	.blog-single-entry.post-minimal > .single-entry-body .single-entry-categories a:not(:last-child):not(:only-child):after { display: none; }

	.blog-single-entry.post-minimal > .single-entry-body > .single-entry-comments a { padding: 5px 10px; }
	.blog-single-entry.post-minimal > .single-entry-body > .single-entry-comments a,
	.blog-single-entry.post-minimal > .single-entry-likes-views .wdt-like-views > div, .blog-single-entry.post-minimal .single-entry-body > .single-entry-likes-views .wdt-like-views > div { border: 1px solid; display: inline-block; font-size: calc(var(--wdtFontSize_Base) - 3px); font-weight: 400; letter-spacing: 1px; line-height: normal; text-transform: none; width: auto; }


	/* Minimal Social Share */

	.blog-single-entry.post-minimal .single-entry-social-share > .share, .blog-single-entry.post-minimal .single-entry-body div.single-entry-social-share > .share { border-width: 0; }
	.blog-single-entry.post-minimal .single-entry-social-share > .share > i, .blog-single-entry.post-minimal .single-entry-body div.single-entry-social-share > .share > i { display: none; }
	.blog-single-entry.post-minimal div[class*="meta-elements-boxed"] .single-entry-social-share > .share ul,
	.blog-single-entry.post-minimal div[class*="meta-elements-boxed"] .single-entry-body div.single-entry-social-share > .share ul,
	.blog-single-entry.post-minimal div[class*="meta-elements-filled"] .single-entry-social-share > .share ul,
	.blog-single-entry.post-minimal div[class*="meta-elements-filled"] .single-entry-body div.single-entry-social-share > .share ul { margin-bottom: 0; }

	.blog-single-entry.post-minimal div[class*="meta-elements-boxed"].entry-social-share-wrapper,
	.blog-single-entry.post-minimal div[class*="meta-elements-filled"].entry-social-share-wrapper { display: flex; }

	.blog-single-entry.post-minimal .single-entry-body .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list:before, .blog-single-entry.post-minimal .single-entry-body .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list:after, .blog-single-entry.post-minimal > .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list:before, .blog-single-entry.post-minimal > .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list:after { content: ''; position: absolute; top: 50%; overflow: hidden; width: 9999px; height: 1px; border-top: 1px solid; margin: 0 30px; }

	.blog-single-entry.post-minimal .single-entry-body .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list:before,
	.blog-single-entry.post-minimal > .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list:before { left: 100%; }

	.blog-single-entry.post-minimal .single-entry-body .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list:after,
	.blog-single-entry.post-minimal > .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list:after { right: 100%; }

	.blog-single-entry.post-minimal .single-entry-body .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list li a, .blog-single-entry.post-minimal > .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list li a { width: 32px; height: 32px; text-align: center; float: left; font-size: 14px; border-radius: 100%; display: flex; justify-content: center; align-items: center; border: 1px solid; }

	.blog-single-entry.post-minimal .single-entry-body .single-entry-social-share:not([class*="meta-elements"]) > .share, .blog-single-entry.post-minimal .single-entry-body .single-entry-social-share:not([class*="meta-elements"]) > .share, .blog-single-entry.post-minimal > .single-entry-social-share:not([class*="meta-elements"]) > .share, .blog-single-entry.post-minimal > .single-entry-social-share:not([class*="meta-elements"]) > .share { display: flex; justify-content: center; align-items: center; overflow: hidden; }

	.blog-single-entry.post-minimal .single-entry-body .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list, .blog-single-entry.post-minimal .single-entry-body .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list, .blog-single-entry.post-minimal > .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list, .blog-single-entry.post-minimal > .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list { display: flex; justify-content: center; align-items: center; position: relative; padding: 0; }

	/* Minimal Author Bio */

	.blog-single-entry.post-minimal > .entry-author-bio, .blog-single-entry.post-minimal > .single-entry-body .entry-author-bio { -webkit-box-shadow: 0 0.3rem 2.9rem 0 rgba(var(--wdtHeadAltColorRgb),0.15); box-shadow: 0 0.3rem 2.9rem 0 rgba(var(--wdtHeadAltColorRgb),0.15); position: relative; text-align: center; padding: 75px 65px 50px; margin: 130px auto 20px; width: 100%; float: left; }

	.blog-single-entry.post-minimal > .single-entry-body + .entry-author-bio { margin-top: 75px; }

	.blog-single-entry.post-minimal > .entry-author-bio .thumb img, .blog-single-entry.post-minimal > .single-entry-body .entry-author-bio .thumb img { border: 2px solid var(--wdtBodyBGColor); margin: auto; position: absolute; left: 0; right: 0; top: 0; width: 110px; -webkit-box-shadow: 0 0.2rem 1.9rem 0 rgba(var(--wdtHeadAltColorRgb),0.15); box-shadow: 0 0.2rem 1.9rem 0 rgba(var(--wdtHeadAltColorRgb),0.15); -webkit-border-radius: 100%; border-radius: 100%; -webkit-transform: translateY(-50%); transform: translateY(-50%); }

	.blog-single-entry.post-minimal > .entry-author-bio .details h3, .blog-single-entry.post-minimal > .single-entry-body .entry-author-bio .details h3 { padding: 0; margin: 0 0 20px; line-height: normal; display: inline-block; position: relative; }

	.blog-single-entry.post-minimal > .entry-author-bio .details h3 span, .blog-single-entry.post-minimal > .single-entry-body .entry-author-bio .details h3 span { font-size: 14px; display: block; text-transform: none; font-weight: 400; }

	.blog-single-entry.post-minimal > .entry-author-bio .details h3 a, .blog-single-entry.post-minimal > .single-entry-body .entry-author-bio .details h3 a { color: var(--wdtHeadAltColor); display: inline-block; font-size: var(--wdtFontSize_H5); margin: 0; text-transform: none; }


	/* Minimal Related Post */

	.blog-single-entry.post-minimal .entry-related-posts {  display: inline-block; margin-bottom: 20px; position: relative; width: 100%; overflow: hidden; text-align: center; }

	.blog-single-entry.post-minimal .entry-related-posts > h4 { display: inline-block; position: relative; font-size: 16px; letter-spacing: 2px; text-transform: uppercase; text-align: center; margin-bottom: 40px; }

	.blog-single-entry.post-minimal .entry-related-posts > h4:before, .blog-single-entry.post-minimal .entry-related-posts > h4:after { content: ''; position: absolute; top: 50%; overflow: hidden; width: 9999px; height: 1px; border-top: 1px solid; margin: 0 30px; }

	.blog-single-entry.post-minimal .entry-related-posts > h4:before { left: 100%; }

	.blog-single-entry.post-minimal .entry-related-posts > h4:after { right: 100%; }

	/* Minimal Pagination */

	.blog-single-entry.post-minimal .entry-post-navigation { clear: both; display: block; float: left; margin: 35px 0 0 !important; 
		position: relative; width: 100%; border-width: 1px; border-style: solid; display: grid; grid-template-columns: repeat(2, 50%); }

     .blog-single-entry.post-minimal .entry-post-navigation > div { overflow: hidden; padding: 40px; width: 100%; display: flex; align-items: center; position: relative; /*height: 190px;*/ }

     .blog-single-entry.post-minimal .entry-post-navigation > div .nav-title-wrap { width: 100%; }
     .blog-single-entry.post-minimal .entry-post-navigation > div *[class*="-bgimg"] ~ .nav-title-wrap { width: calc(100% - 120px); }

     .blog-single-entry.post-minimal .entry-post-navigation > .post-prev-link { justify-content: flex-start; text-align: left; }
     .blog-single-entry.post-minimal .entry-post-navigation > .post-next-link { justify-content: flex-end; text-align: right; border-left-width: 1px; border-style: solid; }

     .blog-single-entry.post-minimal .entry-post-navigation > .post-prev-link > .prev-post-bgimg, 
	 .blog-single-entry.post-minimal .entry-post-navigation > .post-next-link > .next-post-bgimg { 
		background-position: center; background-size: cover; height: 100px; overflow: hidden; position: absolute; top: 50%; width: 100px; 
		-webkit-border-radius: var(--wdtRadius_Zero); border-radius: var(--wdtRadius_Zero); }

     .blog-single-entry.post-minimal .entry-post-navigation > .post-prev-link > .prev-post-bgimg { transform: translate(-50%, -50%); -webkit-transform: translate(-50%, -50%); -moz-transform: translate(-50%, -50%); }
     .blog-single-entry.post-minimal .entry-post-navigation > .post-next-link > .next-post-bgimg { transform: translate(50%, -50%); -webkit-transform: translate(50%, -50%); -moz-transform: translate(50%, -50%); }

     .blog-single-entry.post-minimal .entry-post-navigation > .post-prev-link > .prev-post-bgimg { right: -10px; left: auto;}
     .blog-single-entry.post-minimal .entry-post-navigation > .post-next-link > .next-post-bgimg { left: -10px; right: auto;}

     .blog-single-entry.post-minimal .entry-post-navigation > .post-prev-link > .prev-post-bgimg:before, 
	 .blog-single-entry.post-minimal .entry-post-navigation > .post-next-link > .next-post-bgimg:before { 
		border-width: 0; content: ''; display: block; height: 100%; opacity: 0; position: absolute; 
		top: 0; width: 100%; -webkit-transition:all .3s linear; transition:all .3s linear; display: none; }

     .blog-single-entry.post-minimal .entry-post-navigation > .post-prev-link > .prev-post-bgimg:before,
     .blog-single-entry.post-minimal .entry-post-navigation > .post-next-link > .next-post-bgimg:before {
          background: rgba(var(--wdtHeadAltColorRgb),0.3);
          background: -webkit-radial-gradient(center, ellipse cover, transparent 10%, rgba(var(--wdtHeadAltColorRgb),0.3) 100%);
          background: radial-gradient(transparent 10%, rgba(var(--wdtHeadAltColorRgb),0.3) 100%); }

     .blog-single-entry.post-minimal .entry-post-navigation > .post-prev-link:hover > .prev-post-bgimg:before, 
	 .blog-single-entry.post-minimal .entry-post-navigation > .post-next-link:hover > .next-post-bgimg:before { opacity: 1; }

     .blog-single-entry.post-minimal .entry-post-navigation > div > a { display: block; height: 100%; position: absolute; left: 0; top: 0; width: 100%; z-index: 1; }

     .blog-single-entry.post-minimal .entry-post-navigation > div > a:focus { outline: none; outline-offset: -1px; }

     .blog-single-entry.post-minimal .entry-post-navigation > div > .nav-title-wrap p { display: block; font-size: var(--wdtFontSize_Ext); 
		font-weight: normal; letter-spacing: 3px; line-height: normal; margin: 0 0 10px; position: relative; text-transform: uppercase; width: 100%; 
		-webkit-transition: var(--wdtBaseTransition); transition: var(--wdtBaseTransition); }

     .blog-single-entry.post-minimal .entry-post-navigation > div > .nav-title-wrap h3 { display: block; font-size: var(--wdtFontSize_H6); margin: 0; position: relative; width: 100%; }
     .blog-single-entry.post-minimal .entry-post-navigation > div > .nav-title-wrap h3 a { margin: 0; -webkit-hyphens: auto; hyphens: auto; word-break: break-word; }
     .blog-single-entry.post-minimal .entry-post-navigation > div > .nav-title-wrap span { display: none; }

     article[class*="post-"].blog-single-entry.post-minimal .entry-post-navigation > div.no-post,
     article[class*="post-"].blog-single-entry.post-minimal .entry-post-navigation > div.no-post > .prev-post-bgimg,
	 article[class*="post-"].blog-single-entry.post-minimal .entry-post-navigation > div.no-post > .next-post-bgimg { cursor: not-allowed; }

	 article[class*="post-"].blog-single-entry.post-minimal .entry-post-navigation > div.no-post > .prev-post-bgimg,
	 article[class*="post-"].blog-single-entry.post-minimal .entry-post-navigation > div.no-post > .next-post-bgimg { pointer-events: none; }


    /*----*****---- << Post Minimal Type - Meta Group >> ----*****----*/

    .blog-single-entry.post-minimal div.single-entry-meta-group { float: left; font-size: calc(var(--wdtFontSize_Base) - 2px); font-weight: 300; letter-spacing: 0.5px; margin-bottom: 20px; padding: 50px 50px 45px; position: relative; width: 100%; -webkit-box-shadow: 0 0.3rem 2.9rem 0 rgba(var(--wdtHeadAltColorRgb),0.15); box-shadow: 0 0.3rem 2.9rem 0 rgba(var(--wdtHeadAltColorRgb),0.15); }
    .blog-single-entry.post-minimal div.single-entry-meta-group:not(:first-child) { margin-top: 20px; }
    .blog-single-entry.post-minimal div.single-entry-meta-group:before,.blog-single-entry.post-minimal div.single-entry-meta-group:after { content: ''; height: 20px; margin: 0 auto; position: absolute; left: 0; right: 0; width: 1px; -webkit-transform: translateY(0); transform: translateY(0); }
    .blog-single-entry.post-minimal div.single-entry-meta-group:before { background-color: var(--wdtBodyBGColor); top: 0; }
    .blog-single-entry.post-minimal div.single-entry-meta-group:after { top: -20px; }
    .blog-single-entry.post-minimal div.single-entry-meta-group:hover:before { height: 30px; }
    .blog-single-entry.post-minimal div.single-entry-meta-group:hover:after { top: -10px; height: 10px; }
    .blog-single-entry.post-minimal div.single-entry-meta-group > div { display: inline-block; float: none; margin: 0 0 15px 0; position: relative; width: 49%; }
    .blog-single-entry.post-minimal div.single-entry-meta-group > div:nth-child(odd) { clear: both; float: left; text-align: left; }
    .blog-single-entry.post-minimal div.single-entry-meta-group > div:nth-child(even) { float: right; text-align: right; }
    .blog-single-entry.post-minimal div.single-entry-meta-group > div:nth-child(even) .wdt-like-views > div { float: none; }
    .blog-single-entry.post-minimal div.single-entry-meta-group > div:nth-child(even) .wdt-like-views > div:last-child { margin-right: 0; padding-right: 0; }
    .blog-single-entry.post-minimal div.single-entry-meta-group > div:nth-last-child(-n+2) { margin-bottom: 0; }
    .blog-single-entry.post-minimal div.single-entry-meta-group .author-wrap,.blog-single-entry.post-minimal div.single-entry-meta-group .comment-wrap,
    .blog-single-entry.post-minimal div.single-entry-meta-group .tag-wrap,.blog-single-entry.post-minimal div.single-entry-meta-group .category-wrap { display: inline-block; float: left; margin: 0; padding: 0; position: relative; }
    .blog-single-entry.post-minimal div.single-entry-meta-group .tag-wrap { margin: 0; }
    .blog-single-entry.post-minimal div.single-entry-meta-group > div:nth-child(even) .author-wrap,
    .blog-single-entry.post-minimal div.single-entry-meta-group > div:nth-child(even) .comment-wrap,
    .blog-single-entry.post-minimal div.single-entry-meta-group > div:nth-child(even) .tag-wrap,
    .blog-single-entry.post-minimal div.single-entry-meta-group > div:nth-child(even) .category-wrap { float: right; }

    /* Meta Group - Entry Tags */
    .blog-single-entry.post-minimal div.single-entry-meta-group > .single-entry-tags a,.blog-single-entry.post-minimal > .single-entry-tags a { font-size: 10px; font-weight: 400; letter-spacing: 1px; text-transform: uppercase; border: 1px solid; padding: 5px 10px; line-height: normal; display: inline-block; width: auto; }
    .blog-single-entry.post-minimal div.single-entry-meta-group > .single-entry-tags a:last-child,.blog-single-entry.post-minimal > .single-entry-tags a:last-child { margin-right: 0; }

    /* Meta Group - Social Share */
    .blog-single-entry.post-minimal div.single-entry-meta-group .single-entry-social-share .share,.blog-single-entry.post-minimal .single-entry-social-share .share { border: none; padding: 0; }
    .blog-single-entry.post-minimal div.single-entry-meta-group .single-entry-social-share .share i,.blog-single-entry.post-minimal .single-entry-social-share .share i { display: none; }
    .blog-single-entry.post-minimal div.single-entry-meta-group .share .wdt-share-list { display: inline-block; margin: 0; width: 100%; padding: 0; }
    .blog-single-entry.post-minimal div.single-entry-meta-group .share .wdt-share-list li,.blog-single-entry.post-minimal .single-entry-social-share .share .wdt-share-list li { display: inline-block; margin: 0 5px 0 0; padding-bottom: 0; text-align: center; }
    .blog-single-entry.post-minimal div.single-entry-meta-group .share .wdt-share-list li:last-child,.blog-single-entry.post-minimal .single-entry-social-share .share .wdt-share-list li:last-child { margin-right: 0; }
    .blog-single-entry.post-minimal div.single-entry-meta-group .share .wdt-share-list li a,.blog-single-entry.post-minimal .single-entry-social-share .share .wdt-share-list li a { font-size: 14px; height: 30px; line-height: 30px; text-decoration: none; width: 30px; }
    .blog-single-entry.post-minimal .single-entry-social-share .share i { display: none; }
	.blog-single-entry.post-minimal div.single-entry-meta-group .share .wdt-share-list li a:focus,.blog-single-entry.post-minimal .single-entry-social-share .share .wdt-share-list li a:focus { outline: thin dotted; outline-offset: -3px; }

    /* Meta Group - Likes Views */
	.blog-single-entry.post-minimal div.single-entry-meta-group .single-entry-likes-views .wdt-like-views > div,
	.blog-single-entry.post-minimal > .single-entry-likes-views .wdt-like-views > div { display: inline-block; float: left; margin: 0 10px 5px 0; padding-right: 10px; position: relative; }
	.blog-single-entry.post-minimal div.single-entry-meta-group .single-entry-likes-views .wdt-like-views > div,
	.blog-single-entry.post-minimal > .single-entry-likes-views .wdt-like-views > div { border: 1px solid; padding: 0 0 0 30px; -webkit-transition: var(--wdtBaseTransition); transition: var(--wdtBaseTransition); }
	.blog-single-entry.post-minimal div.single-entry-meta-group .single-entry-likes-views .wdt-like-views > div > i,
	.blog-single-entry.post-minimal > .single-entry-likes-views .wdt-like-views > div > i { border-width: 0; display: flex; align-items: center; justify-content: center; font-size: inherit; line-height: 30px; float: left; height: 100%; margin: 0; position: absolute; left: 0; top: 0; text-align: center; width: 30px; }

	.blog-single-entry.post-minimal div.single-entry-meta-group .single-entry-likes-views .wdt-like-views > div > i:after,
	.blog-single-entry.post-minimal > .single-entry-likes-views .wdt-like-views > div > i:after { border-color: var(--wdtBorderColor); border-style: solid; border-width: 0 1px 0 0; content: ""; display: block; height: 10px; position: absolute; right: 0; top: 50%; -webkit-transform: translateY(-50%); transform: translateY(-50%); }

	.blog-single-entry.post-minimal > .single-entry-likes-views .wdt-like-views > div > a,
	.blog-single-entry.post-minimal div.single-entry-meta-group .single-entry-likes-views .wdt-like-views > div > a,
	.blog-single-entry.post-minimal > .single-entry-likes-views .wdt-like-views > div > span,
	.blog-single-entry.post-minimal div.single-entry-meta-group .single-entry-likes-views .wdt-like-views > div > span { display: inline-block; line-height: 30px; padding: 0 10px; position: relative; text-align: center; }

	.blog-single-entry.post-minimal > .single-entry-likes-views .wdt-like-views > div > a:not(:focus),
    .blog-single-entry.post-minimal div.single-entry-meta-group .single-entry-likes-views .wdt-like-views > div > a:not(:focus) { text-decoration: none; }


    /* Meta Group - Entry Comments */
    .blog-single-entry.post-minimal div.single-entry-meta-group > .single-entry-comments a,.blog-single-entry.post-minimal > .single-entry-comments a { border: 1px solid; display: inline-block; }
    .blog-single-entry.post-minimal div.single-entry-meta-group .single-entry-comments a i,.blog-single-entry.post-minimal .single-entry-comments a i { font-size: inherit; line-height: 30px; float: left; margin: 0; text-align: center; width: 30px; position: absolute; left: 0; top: 0; height: 100%; display: flex; align-items: center; justify-content: center; }

    /* Meta Group - Entry Date */
    .blog-single-entry.post-minimal div.single-entry-meta-group .single-entry-date .date-wrap,.blog-single-entry.post-minimal .single-entry-date .date-wrap { border: 1px solid; display: inline-block; padding: 0 15px 0 42px; text-transform: none; position: relative; }
    .blog-single-entry.post-minimal div.single-entry-meta-group .single-entry-date .date-wrap i,.blog-single-entry.post-minimal .single-entry-date .date-wrap i { font-size: 14px; line-height: 30px; float: left; margin: 0; text-align: center; width: 30px; position: absolute; left: 0; top: 0; height: 100%; display: flex; align-items: center; justify-content: center; }

    /* Meta Group - Entry Author */
    .blog-single-entry.post-minimal div.single-entry-meta-group > .single-entry-author > .author-wrap,.blog-single-entry.post-minimal .single-entry-author > .author-wrap { border: 1px solid; display: inline-block; padding: 0 0 0 28px; position: relative; }
    .blog-single-entry.post-minimal div.single-entry-meta-group > .single-entry-author > .author-wrap > i,.blog-single-entry.post-minimal .single-entry-author > .author-wrap > i { font-size: inherit; line-height: 30px; float: left; margin: 0; text-align: center; width: 30px; position: absolute; left: 0; top: 0; height: 100%; display: flex; align-items: center; justify-content: center; }
    .blog-single-entry.post-minimal div.single-entry-meta-group > .single-entry-author > .author-wrap > a,.blog-single-entry.post-minimal .single-entry-author > .author-wrap > a { display: inline-block; line-height: 30px; padding: 0 10px; position: relative; text-align: center; text-transform: none; }

    /* Meta Group - Entry Category */
    .blog-single-entry.post-minimal .single-entry-categories > .category-wrap { display: inline-block; float: left; margin: 0; padding: 0; position: relative; }
    .blog-single-entry.post-minimal div.single-entry-meta-group > .single-entry-categories > .category-wrap > i,.blog-single-entry.post-minimal .single-entry-categories > .category-wrap > i { float: left; font-size: 14px; height: 30px; line-height: 30px; margin: 0; text-align: center; width: 30px; }
    .blog-single-entry.post-minimal div.single-entry-meta-group > .single-entry-categories > .category-wrap > a,
    .blog-single-entry.post-minimal .single-entry-categories > .category-wrap > a { border: 1px solid; display: inline-block; line-height: 30px; margin: 0 5px 0 0; padding: 0 10px; position: relative; text-align: center; text-transform: none; }
	.blog-single-entry.post-minimal div.single-entry-meta-group .single-entry-categories a:last-child,.blog-single-entry.post-minimal .single-entry-categories a:last-child { margin-right: 0; }


	.blog-single-entry.post-minimal .single-entry-author a:not(:focus), .blog-single-entry.post-minimal .single-entry-tags a:not(:focus), .blog-single-entry.post-minimal .single-entry-categories a:not(:focus), .blog-single-entry.post-minimal .single-entry-comments a:not(:focus) { text-decoration: none; }

	/* Custom style */

	.blog-single-entry.post-minimal .single-entry-body .wdt-custom-blog-detail-list .elementor-icon-list-item { align-items: first baseline; }
	.blog-single-entry.post-minimal .single-entry-body .wdt-custom-blog-detail-list .elementor-icon-list-item .elementor-icon-list-icon i { display: block; }
	.blog-single-entry.post-minimal .single-entry-body .wdt-custom-blog-detail-list .elementor-icon-list-item .elementor-icon-list-icon { margin-top: 8px; }

	.blog-single-entry.post-minimal .single-entry-body .wdt-custom-blog-detail-list .elementor-icon-list-icon + .elementor-icon-list-text { padding-left: 14px; }


/*--------------------------------------------------------------
    Default Colors
--------------------------------------------------------------*/

    .blog-single-entry.post-minimal .post-meta .single-entry-comments .comment-wrap a,

	.blog-single-entry.post-minimal .post-meta .single-entry-author .meta-author-info span,
	.blog-single-entry.post-minimal > .single-entry-tags a, .blog-single-entry.post-minimal > .single-entry-categories a, .blog-single-entry.post-minimal > .single-entry-comments a,

	.blog-single-entry.post-minimal > .single-entry-body > .single-entry-date, .blog-single-entry.post-minimal > .single-entry-date,

	.blog-single-entry.post-minimal .single-entry-body .single-entry-author, .blog-single-entry.post-minimal .single-entry-body .single-entry-author a,

	.blog-single-entry.post-minimal > .single-entry-body .single-entry-tags a, .blog-single-entry.post-minimal > .single-entry-body .single-entry-categories a, .blog-single-entry.post-minimal > .single-entry-body .single-entry-comments a,
	.blog-single-entry.post-minimal .single-entry-likes-views .wdt-like-views > div, .blog-single-entry.post-minimal .single-entry-body .single-entry-likes-views .wdt-like-views > div, .blog-single-entry.post-minimal .single-entry-likes-views .wdt-like-views > div a,

	/* .blog-single-entry.post-minimal .post-header .single-entry-title span.sticky-post,  */
	/* .blog-single-entry.post-minimal > .single-entry-title span.sticky-post,  */
	.blog-single-entry.post-minimal .single-entry-body .single-entry-title span.sticky-post,

    .blog-single-entry.post-minimal div.single-entry-meta-group .single-entry-tags a,.blog-single-entry.post-minimal .single-entry-tags a,

	.blog-single-entry.post-minimal .post-header .single-entry-date, .blog-single-entry.post-minimal > .entry-author-bio .details h3 span, .blog-single-entry.post-minimal > .single-entry-body .entry-author-bio .details h3 span, .blog-single-entry.post-minimal .entry-post-navigation > div > .nav-title-wrap p { color: var(--wdtBodyTxtColor); }

    .blog-single-entry.post-minimal .post-meta .single-entry-author .meta-author-info > a, .blog-single-entry.post-minimal .single-entry-author .meta-author-info > a, .blog-single-entry.post-minimal .entry-post-navigation > div > .nav-title-wrap h3 a, .blog-single-entry.post-minimal .entry-post-navigation > div:hover > .nav-title-wrap p { color: var(--wdtHeadAltColor); }

	.blog-single-entry.post-minimal .post-meta .single-entry-social-share ul li a:hover, .blog-single-entry.post-minimal .single-entry-body .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list li a:hover, .blog-single-entry.post-minimal > .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list li a:hover,

	.blog-single-entry.post-minimal > .single-entry-tags a:hover, .blog-single-entry.post-minimal > .single-entry-categories a:hover, .blog-single-entry.post-minimal > .single-entry-comments a:hover, .blog-single-entry.post-minimal > .single-entry-comments a:hover i, .blog-single-entry.post-minimal > .single-entry-body > .single-entry-tags:hover a, .blog-single-entry.post-minimal > .single-entry-body .single-entry-categories:not(:only-child):hover a, .blog-single-entry.post-minimal > .single-entry-body .single-entry-comments:hover a, .blog-single-entry.post-minimal > .single-entry-body .single-entry-comments a:hover i,
	.blog-single-entry.post-minimal > .single-entry-likes-views .wdt-like-views > div:hover, .blog-single-entry.post-minimal .single-entry-body > .single-entry-likes-views .wdt-like-views > div:hover,
	.blog-single-entry.post-minimal > .single-entry-likes-views .wdt-like-views > div:hover a, .blog-single-entry.post-minimal .single-entry-body > .single-entry-likes-views .wdt-like-views > div:hover a,
	.blog-single-entry.post-minimal > .single-entry-body > .single-entry-date:hover, .blog-single-entry.post-minimal > .single-entry-date:hover,
	.blog-single-entry.post-minimal .single-entry-body div[class*="metagroup-elements-boxed"] .single-entry-author:hover,
	.blog-single-entry.post-minimal .single-entry-body div[class*="metagroup-elements-boxed"] .single-entry-author:hover a,
	.blog-single-entry.post-minimal .post-header .single-entry-title span.sticky-post, .blog-single-entry.post-minimal > .single-entry-title span.sticky-post,
	.blog-single-entry.post-minimal .single-entry-body div[class*="metagroup-elements-boxed"] div[class*="entry-"]:hover .comment-wrap a,
	.blog-single-entry.post-minimal .single-entry-body div[class*="metagroup-elements-boxed"] div[class*="entry-"]:hover *[class*="single-entry-"] a,
	.blog-single-entry.post-minimal .single-entry-body div[class*="metagroup-elements-boxed"] div[class*="single-entry-categories"]:hover a,
	.blog-single-entry.post-minimal .single-entry-body div[class*="metagroup-elements-boxed"] div[class*="single-entry-tags"]:hover a,
	.blog-single-entry.post-minimal .single-entry-body div[class*="metagroup-elements-boxed"] div[class*="single-entry-categories"]:hover a:hover,
	.blog-single-entry.post-minimal .single-entry-body div[class*="metagroup-elements-boxed"] div[class*="single-entry-tags"]:hover a:hover { color: var(--wdtAccentTxtColor); }

	.blog-single-entry.post-minimal .post-header .single-entry-date:before, .blog-single-entry.post-minimal .post-header .single-entry-date:after, .blog-single-entry.post-minimal .post-meta .single-entry-comments .comment-wrap a,
	.blog-single-entry.post-minimal .post-meta .single-entry-comments .comment-wrap a:before,

	.blog-single-entry.post-minimal div.single-entry-meta-group .single-entry-likes-views .wdt-like-views > div > i,
	.blog-single-entry.post-minimal > .single-entry-likes-views .wdt-like-views > div > i,
	.blog-single-entry.post-minimal .single-entry-body .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list:before,
	.blog-single-entry.post-minimal .single-entry-body .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list:after,
	.blog-single-entry.post-minimal > .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list:before,
	.blog-single-entry.post-minimal > .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list:after,
    .blog-single-entry.post-minimal .entry-related-posts > h4:before, .blog-single-entry.post-minimal .entry-related-posts > h4:after { border-color: var(--wdtBorderColor); }

	.blog-single-entry.post-minimal > .single-entry-tags a, .blog-single-entry.post-minimal > .single-entry-categories a, .blog-single-entry.post-minimal > .single-entry-comments a,

	.blog-single-entry.post-minimal > .single-entry-body > .single-entry-tags a, .blog-single-entry.post-minimal > .single-entry-body .single-entry-categories a, .blog-single-entry.post-minimal > .single-entry-body .single-entry-comments a,

	.blog-single-entry.post-minimal > .single-entry-body > .single-entry-date, .blog-single-entry.post-minimal > .single-entry-date,

	.blog-single-entry.post-minimal .single-entry-body .single-entry-author,

	.blog-single-entry.post-minimal > .single-entry-likes-views .wdt-like-views > div, .blog-single-entry.post-minimal .single-entry-body .single-entry-likes-views .wdt-like-views > div,

	/* .blog-single-entry.post-minimal .post-header .single-entry-title span.sticky-post,  */
	/* .blog-single-entry.post-minimal > .single-entry-title span.sticky-post,  */
	.blog-single-entry.post-minimal .single-entry-body .single-entry-title span.sticky-post,

    .blog-single-entry.post-minimal .entry-post-navigation, .blog-single-entry.post-minimal .entry-post-navigation > div,

	.blog-single-entry.post-minimal div.single-entry-meta-group .single-entry-tags a,.blog-single-entry.post-minimal .single-entry-tags a,

	.blog-single-entry.post-minimal .post-meta, .blog-single-entry.post-minimal .meta-time { border-color: rgba(var(--wdtHeadAltColorRgb),0.15); }

	.blog-single-entry.post-minimal .single-entry-body div[class*="meta-elements-boxed"]:hover .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list li a,
	.blog-single-entry.post-minimal .single-entry-body div[class*="meta-elements-filled"] .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list li a { border-color: var(--wdtBodyBGColor); }


	.blog-single-entry.post-minimal .post-meta .single-entry-comments .comment-wrap { -webkit-box-shadow: 0 0 7px rgba(var(--wdtHeadAltColorRgb),0.05); box-shadow: 0 0 7px rgba(var(--wdtHeadAltColorRgb),0.05); }

	.blog-single-entry.post-minimal > .single-entry-body .single-entry-categories:not([class*="meta-elements"]):hover a { color: var(--wdtBodyTxtColor); }


/*--------------------------------------------------------------
    Accents
--------------------------------------------------------------*/

	.blog-single-entry.post-minimal .post-header .single-entry-categories a, .blog-single-entry.post-minimal .post-meta .single-entry-social-share ul li a, .blog-single-entry.post-minimal .single-entry-body .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list li a, .blog-single-entry.post-minimal > .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list li a,
	.blog-single-entry.post-minimal .single-entry-body p:not(.wp-block-cover-text) a:not(.wp-block-button__link):not(.tag-cloud-link):hover, .blog-single-entry [class*="wdt-custom-blockquote"] blockquote:first-child:before, .blog-single-entry.post-minimal .entry-post-navigation > div:hover > .nav-title-wrap h3 a, .blog-single-entry.post-minimal .entry-post-navigation > div > .nav-title-wrap h3 a:hover,
	.blog-single-entry.post-minimal > .single-entry-body .single-entry-categories:only-child a:hover,
	.blog-single-entry.post-minimal > .single-entry-body .single-entry-categories:not([class*="meta-elements"]):hover a:hover,
	.blog-single-entry.post-minimal > .single-entry-body .single-entry-tags a:hover,
	.blog-single-entry.post-minimal > .single-entry-body .single-entry-comments:hover a,
	.blog-single-entry.post-minimal .post-meta .single-entry-author .meta-author-info > a:hover, .blog-single-entry.post-minimal .single-entry-author .meta-author-info > a:hover, .blog-single-entry.post-minimal .entry-post-navigation > div > .nav-title-wrap h3 a:hover { color: var(--wdtPrimaryColor); }

	.blog-single-entry.post-minimal .post-header .single-entry-categories a:hover { color: var(--wdtSecondaryColor); }

	.blog-single-entry.post-minimal .post-meta .single-entry-social-share ul li a, .blog-single-entry.post-minimal .post-meta .single-entry-social-share ul li a:hover,
	.blog-single-entry.post-minimal .single-entry-body .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list li a, .blog-single-entry.post-minimal > .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list li a, .blog-single-entry.post-minimal .single-entry-body .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list li a:hover, .blog-single-entry.post-minimal > .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list li a:hover,

	.blog-single-entry.post-minimal > .single-entry-tags a:hover, .blog-single-entry.post-minimal > .single-entry-categories a:hover, .blog-single-entry.post-minimal > .single-entry-comments a:hover,
	.blog-single-entry.post-minimal > .single-entry-body > .single-entry-tags a:hover, .blog-single-entry.post-minimal > .single-entry-body > .single-entry-categories a:hover,
	.blog-single-entry.post-minimal > .single-entry-body > .single-entry-comments a:hover, .blog-single-entry.post-minimal > .single-entry-likes-views .wdt-like-views > div:hover, .blog-single-entry.post-minimal .single-entry-body > .single-entry-likes-views .wdt-like-views > div:hover, .blog-single-entry.post-minimal > .single-entry-body > .single-entry-date:hover, .blog-single-entry.post-minimal > .single-entry-date:hover,
	.blog-single-entry.post-minimal .single-entry-body div[class*="metagroup-elements-boxed"] .single-entry-author:hover { border-color: var(--wdtPrimaryColor); }

	.blog-single-entry.post-minimal .post-meta .single-entry-social-share ul li a:hover, .blog-single-entry.post-minimal .single-entry-body .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list li a:hover, .blog-single-entry.post-minimal > .single-entry-social-share:not([class*="meta-elements"]) > .share .wdt-share-list li a:hover,

	.blog-single-entry.post-minimal > .single-entry-tags a:hover, .blog-single-entry.post-minimal > .single-entry-categories a:hover, .blog-single-entry.post-minimal > .single-entry-comments a:hover,
	.blog-single-entry.post-minimal > .single-entry-body > .single-entry-tags a:hover, .blog-single-entry.post-minimal > .single-entry-body > .single-entry-categories a:hover,
	.blog-single-entry.post-minimal > .single-entry-body > .single-entry-comments a:hover, .blog-single-entry.post-minimal > .single-entry-likes-views .wdt-like-views > div:hover, .blog-single-entry.post-minimal .single-entry-body > .single-entry-likes-views .wdt-like-views > div:hover, .blog-single-entry.post-minimal > .single-entry-body > .single-entry-date:hover, .blog-single-entry.post-minimal > .single-entry-date:hover, .blog-single-entry.post-minimal .single-entry-body div[class*="metagroup-elements-boxed"] .single-entry-author:hover,
	.blog-single-entry.post-minimal .post-header .single-entry-title span.sticky-post, .blog-single-entry.post-minimal > .single-entry-title span.sticky-post { background-color: var(--wdtPrimaryColor); }

	.blog-single-entry.post-minimal .single-entry-body p a:not(.wp-block-button__link), 
	.blog-single-entry.post-split .single-entry-body p a:not(.wp-block-button__link) { 
		-webkit-box-shadow: inset 0 -1px 0 var(--wdtPrimaryColor); box-shadow: inset 0 -1px 0 var(--wdtPrimaryColor); }

	.blog-single-entry.post-minimal .single-entry-body .wp-block-cover p a:not(.wp-block-button__link), 
	.blog-single-entry.post-split .single-entry-body .wp-block-cover p a:not(.wp-block-button__link) { 
		-webkit-box-shadow: inset 0 -1px 0 var(--wdtAccentTxtColor); box-shadow: inset 0 -1px 0 var(--wdtAccentTxtColor); }

/*--------------------------------------------------------------
Responsive
--------------------------------------------------------------*/

	/*----*****---- << Tablet (Landscape) >> ----*****----*/

	/* Note: Design for a width of 960px */
    @media only screen and (max-width:1280px) {

		.blog-single-entry.post-minimal .post-header,
		.blog-single-entry.post-minimal .post-meta,
		.blog-single-entry.post-minimal .single-entry-body,
		.blog-single-entry.post-minimal .single-entry-body figure figcaption,
		.blog-single-entry.post-minimal #comments { max-width: 100%; }

		.blog-single-entry.post-minimal .entry-post-navigation > div { padding: 50px 30px; }

		.blog-single-entry.post-minimal .entry-post-navigation > .post-prev-link > .prev-post-bgimg { right: -20px; }
		.blog-single-entry.post-minimal .entry-post-navigation > .post-next-link > .next-post-bgimg { left: -20px; }

	}

	/*----*****---- << Mobile (Landscape) >> ----*****----*/

	/* Common Styles for the devices below 767px width */
	@media only screen and (max-width: 767px) {

		.blog-single-entry.post-minimal .entry-post-navigation > div { padding: 30px; }
		.blog-single-entry.post-minimal .entry-post-navigation > div *[class*="-bgimg"] { display: none; }
		.blog-single-entry.post-minimal .entry-post-navigation > div [class*="-bgimg"] ~ .nav-title-wrap { width: 100%; }

		.blog-single-entry.post-minimal .post-meta { padding: 35px 0 20px; }

		.blog-single-entry.post-minimal .post-meta > div { width: 100%; }
		.blog-single-entry.post-minimal .post-meta > [class*="meta"] div[class*="entry-"],
		.blog-single-entry.post-minimal .single-entry-author { text-align: center; flex-wrap: wrap; margin-bottom: 10px; }
		.blog-single-entry.post-minimal .post-meta .single-entry-author { margin-top: 10px !important; }
		.blog-single-entry.post-minimal .post-meta .single-entry-author .meta-author-img,
		.blog-single-entry.post-minimal .single-entry-author .meta-author-img,
		.blog-single-entry.post-minimal .post-meta .single-entry-author .meta-author-info,
		.blog-single-entry.post-minimal .single-entry-author .meta-author-info { width: 100%; margin-right: 0; margin-bottom: 10px; }

		.blog-single-entry.post-minimal .post-meta > [class*="meta"] { justify-content: center; flex-wrap: wrap; }
		.blog-single-entry.post-minimal .post-meta > [class*="meta-right"] div[class*="entry-"] { width: auto; margin-top: 15px; }

		.blog-single-entry.post-minimal .post-meta .single-entry-comments .comment-wrap { margin: 10px 15px; }

		.blog-single-entry.post-minimal > .entry-author-bio, .blog-single-entry.post-minimal > .single-entry-body .entry-author-bio { padding: 75px 35px 50px; }

	}

	 /*----*****---- << Mobile - Portrait >> ----*****----*/

 	/* Common Styles for the devices below 479px width */
 	@media only screen and (max-width: 479px) {

		.blog-single-entry.post-minimal .post-header .single-entry-title h1, .blog-single-entry.post-minimal .single-entry-title h1 { font-size: calc(var(--wdtFontSize_H3) - 2px); }

		.blog-single-entry.post-minimal .entry-post-navigation { grid-template-columns: 1fr; }
		.blog-single-entry.post-minimal .entry-post-navigation > .post-next-link { border-left-width: 0; border-top-width: 1px; }

		.blog-single-entry.post-minimal .entry-post-navigation > .post-prev-link,
		.blog-single-entry.post-minimal .entry-post-navigation > .post-next-link { justify-content: center; text-align: center; }

	}